tiled.trees.files.Tree
======================

.. currentmodule:: tiled.trees.files

.. autoclass:: Tree

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Tree.__init__
      ~Tree.authenticated_as
      ~Tree.from_directory
      ~Tree.get
      ~Tree.items
      ~Tree.keys
      ~Tree.new_variation
      ~Tree.register_query
      ~Tree.register_query_lazy
      ~Tree.search
      ~Tree.shutdown_watcher
      ~Tree.update_now
      ~Tree.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Tree.DEFAULT_MIMETYPES_BY_FILE_EXT
      ~Tree.DEFAULT_READERS_BY_MIMETYPE
      ~Tree.access_policy
      ~Tree.authenticated_identity
      ~Tree.directory
      ~Tree.include_routers
      ~Tree.items_indexer
      ~Tree.keys_indexer
      ~Tree.metadata
      ~Tree.query_registry
      ~Tree.values_indexer
   
   